<!doctype html>
{% include "redberry/_macros.html" %}

<html>
    <head>
        {% include "redberry/_head.html" %}

        {% block head %}{% endblock %}
    </head>


    <body>
        {% with messages = get_flashed_messages(with_categories=true) %}
            {% if messages %}
                {% for category, message in messages %}
                    <div class="flashes alert alert-{{ category }}">
                        <div class="container">
                            {{ message }}
                            <button type="button" class="close" data-dismiss="alert">
                                <span>&times;</span>
                            </button>
                        </div>
                    </div>
                {% endfor %}
            {% endif %}
        {% endwith %}
        {% block content %}{% endblock %}

        <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.min.js"></script>
        <script type="text/javascript" src="{{ url_for('redberry.static', filename='js/redberry.js')}}"></script>
        {% block javascript %}{% endblock %}
    </body>
</html>